# Contributions to `teslajsonpy`

## Owners

-   Sergey Isachenko [GitHub](https://github.com/zabuldon)

## Maintainers

-   Alan Tse [GitLab](https://gitlab.com/alandtse) [GitHub](https://github.com/alandtse)

## Contributors

-   ultratoto14 [GitHub](https://github.com/ultratoto14)
-   johanjongsma [GitHub](https://github.com/johanjongsma)
-   hobbe [GitHub](https://github.com/hobbe)
